# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!--
The rules for this file:
  * entries are sorted newest-first.
  * summarize sets of changes - don't reproduce every git log comment here.
  * don't ever delete anything.
  * keep the format consistent:
    * do not use tabs but use spaces for formatting
    * 79 char width
    * YYYY-MM-DD date format (following ISO 8601)
  * accompany each entry with github issue/PR number (Issue #xyz)
-->

## 0.2.0
 * [New] Include segmentid for freesasa calculation.
 * [New] Calculate area contributed per residue

## 0.1.2 
 * [Fix] Clean area calculation

## 0.1.1
 * [Fix] Area surface to be a floating type

### 0.1
 * [New] Calculate the area of a full pdb protein

